Cell class

A data class for terminal cells.

Constructors

Cell({required int row, required int column, String character = ' ', String color = 'white'})

Properties

character String
The current character stored in the cell.
getter/setter pair
color String
The current color of the cell's display.
getter/setter pair
column int
The row the cell maps to in the terminal.
final
hashCode int
The hash code for this object.
no setteroverride
row int
The row the cell maps to in the terminal.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyValuesOf(Cell other) → void
Copies data from another cell.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override